# This file was auto-generated by Fern from our API Definition.

import contextlib
import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from ..types.response import Response
from ..types.response_dict import ResponseDict
from ..types.response_list import ResponseList
from ..types.response_str import ResponseStr
from .types.navigate_request_wait_until import NavigateRequestWaitUntil
from .types.record_request_action import RecordRequestAction
from .types.type import Type

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawBrowserPageClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def navigate(
        self,
        *,
        url: str,
        wait_until: typing.Optional[NavigateRequestWaitUntil] = OMIT,
        timeout: typing.Optional[float] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ResponseDict]:
        """
        Navigate the current page to a URL.

        Parameters
        ----------
        url : str

        wait_until : typing.Optional[NavigateRequestWaitUntil]

        timeout : typing.Optional[float]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ResponseDict]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/navigate",
            method="POST",
            json={
                "url": url,
                "wait_until": wait_until,
                "timeout": timeout,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseDict,
                    parse_obj_as(
                        type_=ResponseDict,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def back(self, *, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[Response]:
        """
        Go back in browser history.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/back",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def forward(self, *, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[Response]:
        """
        Go forward in browser history.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/forward",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def reload(self, *, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[Response]:
        """
        Reload the current page.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/reload",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def click(
        self,
        *,
        selector: typing.Optional[str] = OMIT,
        index: typing.Optional[int] = OMIT,
        x: typing.Optional[float] = OMIT,
        y: typing.Optional[float] = OMIT,
        button: typing.Optional[str] = OMIT,
        click_count: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[Response]:
        """
        Click an element by selector, index, or coordinates.

        Parameters
        ----------
        selector : typing.Optional[str]

        index : typing.Optional[int]

        x : typing.Optional[float]

        y : typing.Optional[float]

        button : typing.Optional[str]

        click_count : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/click",
            method="POST",
            json={
                "selector": selector,
                "index": index,
                "x": x,
                "y": y,
                "button": button,
                "click_count": click_count,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def fill(
        self,
        *,
        text: str,
        selector: typing.Optional[str] = OMIT,
        index: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[Response]:
        """
        Fill an input field.

        Parameters
        ----------
        text : str

        selector : typing.Optional[str]

        index : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/fill",
            method="POST",
            json={
                "selector": selector,
                "index": index,
                "text": text,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def type_text(
        self,
        *,
        text: str,
        delay: typing.Optional[float] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[Response]:
        """
        Type text with optional delay between keystrokes.

        Parameters
        ----------
        text : str

        delay : typing.Optional[float]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/type",
            method="POST",
            json={
                "text": text,
                "delay": delay,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def press_key(self, *, key: str, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[Response]:
        """
        Press a single key.

        Parameters
        ----------
        key : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/press_key",
            method="POST",
            json={
                "key": key,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def hot_key(
        self, *, keys: typing.Sequence[str], request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[Response]:
        """
        Press a key combination.

        Parameters
        ----------
        keys : typing.Sequence[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/hot_key",
            method="POST",
            json={
                "keys": keys,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def hover(
        self,
        *,
        selector: typing.Optional[str] = OMIT,
        x: typing.Optional[float] = OMIT,
        y: typing.Optional[float] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[Response]:
        """
        Hover over an element by selector or coordinates.

        Parameters
        ----------
        selector : typing.Optional[str]

        x : typing.Optional[float]

        y : typing.Optional[float]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/hover",
            method="POST",
            json={
                "selector": selector,
                "x": x,
                "y": y,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def select_option(
        self,
        *,
        selector: str,
        value: typing.Optional[str] = OMIT,
        label: typing.Optional[str] = OMIT,
        index: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[Response]:
        """
        Select an option in a dropdown.

        Parameters
        ----------
        selector : str

        value : typing.Optional[str]

        label : typing.Optional[str]

        index : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/select_option",
            method="POST",
            json={
                "selector": selector,
                "value": value,
                "label": label,
                "index": index,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def check(
        self, *, selector: str, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[Response]:
        """
        Check a checkbox.

        Parameters
        ----------
        selector : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/check",
            method="POST",
            json={
                "selector": selector,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def uncheck(
        self, *, selector: str, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[Response]:
        """
        Uncheck a checkbox.

        Parameters
        ----------
        selector : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/uncheck",
            method="POST",
            json={
                "selector": selector,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def upload_file(
        self, *, selector: str, files: typing.Sequence[str], request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[Response]:
        """
        Upload files to a file input element.

        Parameters
        ----------
        selector : str

        files : typing.Sequence[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/upload_file",
            method="POST",
            json={
                "selector": selector,
                "files": files,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def fill_form(
        self,
        *,
        items: typing.Sequence[typing.Dict[str, typing.Optional[typing.Any]]],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[Response]:
        """
        Batch fill multiple form fields.

        Parameters
        ----------
        items : typing.Sequence[typing.Dict[str, typing.Optional[typing.Any]]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/fill_form",
            method="POST",
            json={
                "items": items,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def scroll(
        self,
        *,
        direction: typing.Optional[str] = OMIT,
        amount: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[Response]:
        """
        Scroll the page in a direction.

        Parameters
        ----------
        direction : typing.Optional[str]

        amount : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/scroll",
            method="POST",
            json={
                "direction": direction,
                "amount": amount,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def scroll_to(
        self,
        *,
        x: typing.Optional[int] = OMIT,
        y: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[Response]:
        """
        Scroll to an absolute position.

        Parameters
        ----------
        x : typing.Optional[int]

        y : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/scroll_to",
            method="POST",
            json={
                "x": x,
                "y": y,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def scroll_to_element(
        self, *, selector: str, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[Response]:
        """
        Scroll an element into view.

        Parameters
        ----------
        selector : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/scroll_to_element",
            method="POST",
            json={
                "selector": selector,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    @contextlib.contextmanager
    def screenshot(
        self,
        *,
        full_page: typing.Optional[bool] = None,
        format: typing.Optional[str] = None,
        quality: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[HttpResponse[typing.Iterator[bytes]]]:
        """
        Capture a page screenshot.

        Parameters
        ----------
        full_page : typing.Optional[bool]

        format : typing.Optional[str]

        quality : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.Iterator[HttpResponse[typing.Iterator[bytes]]]
            Page-level screenshot via Playwright
        """
        with self._client_wrapper.httpx_client.stream(
            "v1/browser/page/screenshot",
            method="GET",
            params={
                "full_page": full_page,
                "format": format,
                "quality": quality,
            },
            request_options=request_options,
        ) as _response:

            def _stream() -> HttpResponse[typing.Iterator[bytes]]:
                try:
                    if 200 <= _response.status_code < 300:
                        _chunk_size = request_options.get("chunk_size", None) if request_options is not None else None
                        return HttpResponse(
                            response=_response, data=(_chunk for _chunk in _response.iter_bytes(chunk_size=_chunk_size))
                        )
                    _response.read()
                    if _response.status_code == 422:
                        raise UnprocessableEntityError(
                            headers=dict(_response.headers),
                            body=typing.cast(
                                HttpValidationError,
                                parse_obj_as(
                                    type_=HttpValidationError,  # type: ignore
                                    object_=_response.json(),
                                ),
                            ),
                        )
                    _response_json = _response.json()
                except JSONDecodeError:
                    raise ApiError(
                        status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
                    )
                raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

            yield _stream()

    def record(
        self,
        *,
        action: typing.Optional[RecordRequestAction] = OMIT,
        save_path: typing.Optional[str] = OMIT,
        duration: typing.Optional[float] = OMIT,
        fps: typing.Optional[int] = OMIT,
        quality: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ResponseDict]:
        """
        Record page screencast (once/start/pause/resume/stop/status).

        Parameters
        ----------
        action : typing.Optional[RecordRequestAction]

        save_path : typing.Optional[str]

        duration : typing.Optional[float]

        fps : typing.Optional[int]

        quality : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ResponseDict]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/record",
            method="POST",
            json={
                "action": action,
                "save_path": save_path,
                "duration": duration,
                "fps": fps,
                "quality": quality,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseDict,
                    parse_obj_as(
                        type_=ResponseDict,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_html(
        self, *, outer: typing.Optional[bool] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ResponseStr]:
        """
        Get the page HTML content.

        Parameters
        ----------
        outer : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ResponseStr]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/html",
            method="GET",
            params={
                "outer": outer,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseStr,
                    parse_obj_as(
                        type_=ResponseStr,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_text(self, *, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[ResponseStr]:
        """
        Get all visible text from the page.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ResponseStr]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/text",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseStr,
                    parse_obj_as(
                        type_=ResponseStr,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_markdown(self, *, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[ResponseDict]:
        """
        Get the page content as Markdown using Readability and Turndown.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ResponseDict]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/markdown",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseDict,
                    parse_obj_as(
                        type_=ResponseDict,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_elements(self, *, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[ResponseList]:
        """
        Get all interactive elements on the page.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ResponseList]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/elements",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseList,
                    parse_obj_as(
                        type_=ResponseList,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_console(
        self, *, clear: typing.Optional[bool] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ResponseList]:
        """
        Get captured browser console log messages.

        Parameters
        ----------
        clear : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ResponseList]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/console",
            method="GET",
            params={
                "clear": clear,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseList,
                    parse_obj_as(
                        type_=ResponseList,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def export_console(
        self,
        *,
        save_path: str,
        clear: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[Response]:
        """
        Export console logs to a JSON file.

        Parameters
        ----------
        save_path : str

        clear : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/console/export",
            method="POST",
            json={
                "save_path": save_path,
                "clear": clear,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def evaluate(
        self, *, expression: str, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[Response]:
        """
        Execute JavaScript and return the result.

        Parameters
        ----------
        expression : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/evaluate",
            method="POST",
            json={
                "expression": expression,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def find_text(
        self, *, keyword: str, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ResponseList]:
        """
        Find text occurrences on the page.

        Parameters
        ----------
        keyword : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ResponseList]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/find_text",
            method="POST",
            json={
                "keyword": keyword,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseList,
                    parse_obj_as(
                        type_=ResponseList,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def wait(
        self,
        *,
        type: Type,
        selector: typing.Optional[str] = OMIT,
        state: typing.Optional[str] = OMIT,
        url: typing.Optional[str] = OMIT,
        save_path: typing.Optional[str] = OMIT,
        timeout: typing.Optional[float] = OMIT,
        expression: typing.Optional[str] = OMIT,
        polling: typing.Optional[float] = OMIT,
        url_pattern: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[Response]:
        """
        Unified wait: selector, load, url, network_idle, download, function, response, request, or timeout.

        Parameters
        ----------
        type : Type

        selector : typing.Optional[str]

        state : typing.Optional[str]

        url : typing.Optional[str]

        save_path : typing.Optional[str]

        timeout : typing.Optional[float]

        expression : typing.Optional[str]

        polling : typing.Optional[float]

        url_pattern : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Response]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/browser/page/wait",
            method="POST",
            json={
                "type": type,
                "selector": selector,
                "state": state,
                "url": url,
                "save_path": save_path,
                "timeout": timeout,
                "expression": expression,
                "polling": polling,
                "url_pattern": url_pattern,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawBrowserPageClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def navigate(
        self,
        *,
        url: str,
        wait_until: typing.Optional[NavigateRequestWaitUntil] = OMIT,
        timeout: typing.Optional[float] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ResponseDict]:
        """
        Navigate the current page to a URL.

        Parameters
        ----------
        url : str

        wait_until : typing.Optional[NavigateRequestWaitUntil]

        timeout : typing.Optional[float]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ResponseDict]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/navigate",
            method="POST",
            json={
                "url": url,
                "wait_until": wait_until,
                "timeout": timeout,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseDict,
                    parse_obj_as(
                        type_=ResponseDict,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def back(self, *, request_options: typing.Optional[RequestOptions] = None) -> AsyncHttpResponse[Response]:
        """
        Go back in browser history.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/back",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def forward(self, *, request_options: typing.Optional[RequestOptions] = None) -> AsyncHttpResponse[Response]:
        """
        Go forward in browser history.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/forward",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def reload(self, *, request_options: typing.Optional[RequestOptions] = None) -> AsyncHttpResponse[Response]:
        """
        Reload the current page.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/reload",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def click(
        self,
        *,
        selector: typing.Optional[str] = OMIT,
        index: typing.Optional[int] = OMIT,
        x: typing.Optional[float] = OMIT,
        y: typing.Optional[float] = OMIT,
        button: typing.Optional[str] = OMIT,
        click_count: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[Response]:
        """
        Click an element by selector, index, or coordinates.

        Parameters
        ----------
        selector : typing.Optional[str]

        index : typing.Optional[int]

        x : typing.Optional[float]

        y : typing.Optional[float]

        button : typing.Optional[str]

        click_count : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/click",
            method="POST",
            json={
                "selector": selector,
                "index": index,
                "x": x,
                "y": y,
                "button": button,
                "click_count": click_count,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def fill(
        self,
        *,
        text: str,
        selector: typing.Optional[str] = OMIT,
        index: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[Response]:
        """
        Fill an input field.

        Parameters
        ----------
        text : str

        selector : typing.Optional[str]

        index : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/fill",
            method="POST",
            json={
                "selector": selector,
                "index": index,
                "text": text,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def type_text(
        self,
        *,
        text: str,
        delay: typing.Optional[float] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[Response]:
        """
        Type text with optional delay between keystrokes.

        Parameters
        ----------
        text : str

        delay : typing.Optional[float]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/type",
            method="POST",
            json={
                "text": text,
                "delay": delay,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def press_key(
        self, *, key: str, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[Response]:
        """
        Press a single key.

        Parameters
        ----------
        key : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/press_key",
            method="POST",
            json={
                "key": key,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def hot_key(
        self, *, keys: typing.Sequence[str], request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[Response]:
        """
        Press a key combination.

        Parameters
        ----------
        keys : typing.Sequence[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/hot_key",
            method="POST",
            json={
                "keys": keys,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def hover(
        self,
        *,
        selector: typing.Optional[str] = OMIT,
        x: typing.Optional[float] = OMIT,
        y: typing.Optional[float] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[Response]:
        """
        Hover over an element by selector or coordinates.

        Parameters
        ----------
        selector : typing.Optional[str]

        x : typing.Optional[float]

        y : typing.Optional[float]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/hover",
            method="POST",
            json={
                "selector": selector,
                "x": x,
                "y": y,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def select_option(
        self,
        *,
        selector: str,
        value: typing.Optional[str] = OMIT,
        label: typing.Optional[str] = OMIT,
        index: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[Response]:
        """
        Select an option in a dropdown.

        Parameters
        ----------
        selector : str

        value : typing.Optional[str]

        label : typing.Optional[str]

        index : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/select_option",
            method="POST",
            json={
                "selector": selector,
                "value": value,
                "label": label,
                "index": index,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def check(
        self, *, selector: str, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[Response]:
        """
        Check a checkbox.

        Parameters
        ----------
        selector : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/check",
            method="POST",
            json={
                "selector": selector,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def uncheck(
        self, *, selector: str, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[Response]:
        """
        Uncheck a checkbox.

        Parameters
        ----------
        selector : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/uncheck",
            method="POST",
            json={
                "selector": selector,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def upload_file(
        self, *, selector: str, files: typing.Sequence[str], request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[Response]:
        """
        Upload files to a file input element.

        Parameters
        ----------
        selector : str

        files : typing.Sequence[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/upload_file",
            method="POST",
            json={
                "selector": selector,
                "files": files,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def fill_form(
        self,
        *,
        items: typing.Sequence[typing.Dict[str, typing.Optional[typing.Any]]],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[Response]:
        """
        Batch fill multiple form fields.

        Parameters
        ----------
        items : typing.Sequence[typing.Dict[str, typing.Optional[typing.Any]]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/fill_form",
            method="POST",
            json={
                "items": items,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def scroll(
        self,
        *,
        direction: typing.Optional[str] = OMIT,
        amount: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[Response]:
        """
        Scroll the page in a direction.

        Parameters
        ----------
        direction : typing.Optional[str]

        amount : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/scroll",
            method="POST",
            json={
                "direction": direction,
                "amount": amount,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def scroll_to(
        self,
        *,
        x: typing.Optional[int] = OMIT,
        y: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[Response]:
        """
        Scroll to an absolute position.

        Parameters
        ----------
        x : typing.Optional[int]

        y : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/scroll_to",
            method="POST",
            json={
                "x": x,
                "y": y,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def scroll_to_element(
        self, *, selector: str, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[Response]:
        """
        Scroll an element into view.

        Parameters
        ----------
        selector : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/scroll_to_element",
            method="POST",
            json={
                "selector": selector,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    @contextlib.asynccontextmanager
    async def screenshot(
        self,
        *,
        full_page: typing.Optional[bool] = None,
        format: typing.Optional[str] = None,
        quality: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[AsyncHttpResponse[typing.AsyncIterator[bytes]]]:
        """
        Capture a page screenshot.

        Parameters
        ----------
        full_page : typing.Optional[bool]

        format : typing.Optional[str]

        quality : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.AsyncIterator[AsyncHttpResponse[typing.AsyncIterator[bytes]]]
            Page-level screenshot via Playwright
        """
        async with self._client_wrapper.httpx_client.stream(
            "v1/browser/page/screenshot",
            method="GET",
            params={
                "full_page": full_page,
                "format": format,
                "quality": quality,
            },
            request_options=request_options,
        ) as _response:

            async def _stream() -> AsyncHttpResponse[typing.AsyncIterator[bytes]]:
                try:
                    if 200 <= _response.status_code < 300:
                        _chunk_size = request_options.get("chunk_size", None) if request_options is not None else None
                        return AsyncHttpResponse(
                            response=_response,
                            data=(_chunk async for _chunk in _response.aiter_bytes(chunk_size=_chunk_size)),
                        )
                    await _response.aread()
                    if _response.status_code == 422:
                        raise UnprocessableEntityError(
                            headers=dict(_response.headers),
                            body=typing.cast(
                                HttpValidationError,
                                parse_obj_as(
                                    type_=HttpValidationError,  # type: ignore
                                    object_=_response.json(),
                                ),
                            ),
                        )
                    _response_json = _response.json()
                except JSONDecodeError:
                    raise ApiError(
                        status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
                    )
                raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

            yield await _stream()

    async def record(
        self,
        *,
        action: typing.Optional[RecordRequestAction] = OMIT,
        save_path: typing.Optional[str] = OMIT,
        duration: typing.Optional[float] = OMIT,
        fps: typing.Optional[int] = OMIT,
        quality: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ResponseDict]:
        """
        Record page screencast (once/start/pause/resume/stop/status).

        Parameters
        ----------
        action : typing.Optional[RecordRequestAction]

        save_path : typing.Optional[str]

        duration : typing.Optional[float]

        fps : typing.Optional[int]

        quality : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ResponseDict]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/record",
            method="POST",
            json={
                "action": action,
                "save_path": save_path,
                "duration": duration,
                "fps": fps,
                "quality": quality,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseDict,
                    parse_obj_as(
                        type_=ResponseDict,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_html(
        self, *, outer: typing.Optional[bool] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ResponseStr]:
        """
        Get the page HTML content.

        Parameters
        ----------
        outer : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ResponseStr]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/html",
            method="GET",
            params={
                "outer": outer,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseStr,
                    parse_obj_as(
                        type_=ResponseStr,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_text(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ResponseStr]:
        """
        Get all visible text from the page.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ResponseStr]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/text",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseStr,
                    parse_obj_as(
                        type_=ResponseStr,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_markdown(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ResponseDict]:
        """
        Get the page content as Markdown using Readability and Turndown.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ResponseDict]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/markdown",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseDict,
                    parse_obj_as(
                        type_=ResponseDict,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_elements(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ResponseList]:
        """
        Get all interactive elements on the page.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ResponseList]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/elements",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseList,
                    parse_obj_as(
                        type_=ResponseList,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_console(
        self, *, clear: typing.Optional[bool] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ResponseList]:
        """
        Get captured browser console log messages.

        Parameters
        ----------
        clear : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ResponseList]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/console",
            method="GET",
            params={
                "clear": clear,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseList,
                    parse_obj_as(
                        type_=ResponseList,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def export_console(
        self,
        *,
        save_path: str,
        clear: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[Response]:
        """
        Export console logs to a JSON file.

        Parameters
        ----------
        save_path : str

        clear : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/console/export",
            method="POST",
            json={
                "save_path": save_path,
                "clear": clear,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def evaluate(
        self, *, expression: str, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[Response]:
        """
        Execute JavaScript and return the result.

        Parameters
        ----------
        expression : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/evaluate",
            method="POST",
            json={
                "expression": expression,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def find_text(
        self, *, keyword: str, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ResponseList]:
        """
        Find text occurrences on the page.

        Parameters
        ----------
        keyword : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ResponseList]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/find_text",
            method="POST",
            json={
                "keyword": keyword,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResponseList,
                    parse_obj_as(
                        type_=ResponseList,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def wait(
        self,
        *,
        type: Type,
        selector: typing.Optional[str] = OMIT,
        state: typing.Optional[str] = OMIT,
        url: typing.Optional[str] = OMIT,
        save_path: typing.Optional[str] = OMIT,
        timeout: typing.Optional[float] = OMIT,
        expression: typing.Optional[str] = OMIT,
        polling: typing.Optional[float] = OMIT,
        url_pattern: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[Response]:
        """
        Unified wait: selector, load, url, network_idle, download, function, response, request, or timeout.

        Parameters
        ----------
        type : Type

        selector : typing.Optional[str]

        state : typing.Optional[str]

        url : typing.Optional[str]

        save_path : typing.Optional[str]

        timeout : typing.Optional[float]

        expression : typing.Optional[str]

        polling : typing.Optional[float]

        url_pattern : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Response]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/browser/page/wait",
            method="POST",
            json={
                "type": type,
                "selector": selector,
                "state": state,
                "url": url,
                "save_path": save_path,
                "timeout": timeout,
                "expression": expression,
                "polling": polling,
                "url_pattern": url_pattern,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    Response,
                    parse_obj_as(
                        type_=Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        ActionData,
        ActionResponse,
        ActiveSessionsResult,
        ActiveShellSessionsResult,
        Annotations,
        AnnotationsAudienceItem,
        AudioContent,
        AvailableTool,
        BashCommandInfo,
        BashCommandStatus,
        BashExecResult,
        BashOutputResult,
        BashSessionInfo,
        BlobResourceContents,
        BrowserInfoResult,
        BrowserViewport,
        Button,
        CallToolResult,
        CaptchaWaitResult,
        CheckRequest,
        ClickAction,
        CodeExecuteResponse,
        CodeInfoResponse,
        CodeLanguageInfo,
        CommandStatus,
        ConsoleRecord,
        DependencyCommandResult,
        DoubleClickAction,
        DragRelAction,
        DragToAction,
        EmbeddedResource,
        FileContentEncoding,
        FileFindResult,
        FileGlobResult,
        FileGrepResult,
        FileInfo,
        FileListResult,
        FileReadResult,
        FileReplaceResult,
        FileSearchResult,
        FileUploadResult,
        FileWriteResult,
        GlobFileInfo,
        GrepMatch,
        HotkeyAction,
        HttpValidationError,
        Icon,
        ImageContent,
        JupyterCreateSessionResponse,
        JupyterExecuteResponse,
        JupyterInfoResponse,
        JupyterOutput,
        KeyDownAction,
        KeyUpAction,
        Language,
        ListToolsResult,
        Mode,
        MouseDownAction,
        MouseUpAction,
        MoveRelAction,
        MoveToAction,
        NodeJsCreateSessionResponse,
        NodeJsDeleteSessionResponse,
        NodeJsExecuteResponse,
        NodeJsOutput,
        NodeJsPackageInfo,
        NodeJsRuntimeInfo,
        NodeJsSessionInfo,
        NodeJsSessionListResponse,
        NodeJsSessionResponse,
        NodeJsUpdateSessionResponse,
        PressAction,
        ProxyBypassRequest,
        ProxyDiagnoseResult,
        ProxyMappingRoute,
        ProxyUpstreamInfo,
        Resolution,
        Resource,
        ResourceLink,
        Response,
        ResponseActiveSessionsResult,
        ResponseActiveShellSessionsResult,
        ResponseBashExecResult,
        ResponseBashOutputResult,
        ResponseBashSessionInfo,
        ResponseBrowserInfoResult,
        ResponseCallToolResultModel,
        ResponseCallToolResultModelDataContentItem,
        ResponseCallToolResultModelDataContentItem_Audio,
        ResponseCallToolResultModelDataContentItem_Image,
        ResponseCallToolResultModelDataContentItem_Resource,
        ResponseCallToolResultModelDataContentItem_ResourceLink,
        ResponseCallToolResultModelDataContentItem_Text,
        ResponseCaptchaWaitResult,
        ResponseCodeExecuteResponse,
        ResponseCodeInfoResponse,
        ResponseDict,
        ResponseFileFindResult,
        ResponseFileGlobResult,
        ResponseFileGrepResult,
        ResponseFileListResult,
        ResponseFileReadResult,
        ResponseFileReplaceResult,
        ResponseFileSearchResult,
        ResponseFileUploadResult,
        ResponseFileWriteResult,
        ResponseJupyterCreateSessionResponse,
        ResponseJupyterExecuteResponse,
        ResponseJupyterInfoResponse,
        ResponseList,
        ResponseListBashSessionInfo,
        ResponseListProxyMappingRoute,
        ResponseListStr,
        ResponseListToolsResultModel,
        ResponseNodeJsCreateSessionResponse,
        ResponseNodeJsDeleteSessionResponse,
        ResponseNodeJsExecuteResponse,
        ResponseNodeJsRuntimeInfo,
        ResponseNodeJsSessionListResponse,
        ResponseNodeJsSessionResponse,
        ResponseNodeJsUpdateSessionResponse,
        ResponseProxyDiagnoseResult,
        ResponseProxyMappingRoute,
        ResponseProxyUpstreamInfo,
        ResponseShellCommandResult,
        ResponseShellCreateSessionResponse,
        ResponseShellKillResult,
        ResponseShellViewResult,
        ResponseShellWaitResult,
        ResponseShellWriteResult,
        ResponseSkillContentResult,
        ResponseSkillMetadata,
        ResponseSkillMetadataCollection,
        ResponseSkillRegistrationResult,
        ResponseStr,
        ResponseStrReplaceEditorResult,
        ResponseUnionProxyUpstreamInfoNoneType,
        RestartRequest,
        RightClickAction,
        RouteResponseModel,
        RuntimeEnv,
        SandboxDetail,
        SandboxResponse,
        ScrollAction,
        SessionInfo,
        SessionStatus,
        ShellCommandResult,
        ShellCreateSessionResponse,
        ShellKillResult,
        ShellSessionInfo,
        ShellViewResult,
        ShellWaitResult,
        ShellWriteResult,
        SkillContentResult,
        SkillMetadata,
        SkillMetadataCollection,
        SkillRegistrationResult,
        StrReplaceEditorResult,
        SystemEnv,
        TextContent,
        TextResourceContents,
        Tool,
        ToolAnnotations,
        ToolCategory,
        ToolExecution,
        ToolExecutionTaskSupport,
        ToolSpec,
        TypingAction,
        ValidationError,
        ValidationErrorLocItem,
        WaitAction,
    )
    from .errors import UnprocessableEntityError
    from . import (
        auth,
        bash,
        browser,
        browser_captcha,
        browser_cookies,
        browser_network,
        browser_page,
        browser_state,
        browser_tabs,
        code,
        file,
        jupyter,
        mcp,
        nodejs,
        proxy,
        sandbox,
        shell,
        skills,
        util,
    )
    from .browser import (
        Action,
        Action_Click,
        Action_DoubleClick,
        Action_DragRel,
        Action_DragTo,
        Action_Hotkey,
        Action_KeyDown,
        Action_KeyUp,
        Action_MouseDown,
        Action_MouseUp,
        Action_MoveRel,
        Action_MoveTo,
        Action_Press,
        Action_RightClick,
        Action_Scroll,
        Action_Typing,
        Action_Wait,
    )
    from .browser_page import NavigateRequestWaitUntil, RecordRequestAction, Type
    from .client import AsyncSandbox, Sandbox
    from .file import Command, StrReplaceEditorRequestReplaceMode
_dynamic_imports: typing.Dict[str, str] = {
    "Action": ".browser",
    "ActionData": ".types",
    "ActionResponse": ".types",
    "Action_Click": ".browser",
    "Action_DoubleClick": ".browser",
    "Action_DragRel": ".browser",
    "Action_DragTo": ".browser",
    "Action_Hotkey": ".browser",
    "Action_KeyDown": ".browser",
    "Action_KeyUp": ".browser",
    "Action_MouseDown": ".browser",
    "Action_MouseUp": ".browser",
    "Action_MoveRel": ".browser",
    "Action_MoveTo": ".browser",
    "Action_Press": ".browser",
    "Action_RightClick": ".browser",
    "Action_Scroll": ".browser",
    "Action_Typing": ".browser",
    "Action_Wait": ".browser",
    "ActiveSessionsResult": ".types",
    "ActiveShellSessionsResult": ".types",
    "Annotations": ".types",
    "AnnotationsAudienceItem": ".types",
    "AsyncSandbox": ".client",
    "AudioContent": ".types",
    "AvailableTool": ".types",
    "BashCommandInfo": ".types",
    "BashCommandStatus": ".types",
    "BashExecResult": ".types",
    "BashOutputResult": ".types",
    "BashSessionInfo": ".types",
    "BlobResourceContents": ".types",
    "BrowserInfoResult": ".types",
    "BrowserViewport": ".types",
    "Button": ".types",
    "CallToolResult": ".types",
    "CaptchaWaitResult": ".types",
    "CheckRequest": ".types",
    "ClickAction": ".types",
    "CodeExecuteResponse": ".types",
    "CodeInfoResponse": ".types",
    "CodeLanguageInfo": ".types",
    "Command": ".file",
    "CommandStatus": ".types",
    "ConsoleRecord": ".types",
    "DependencyCommandResult": ".types",
    "DoubleClickAction": ".types",
    "DragRelAction": ".types",
    "DragToAction": ".types",
    "EmbeddedResource": ".types",
    "FileContentEncoding": ".types",
    "FileFindResult": ".types",
    "FileGlobResult": ".types",
    "FileGrepResult": ".types",
    "FileInfo": ".types",
    "FileListResult": ".types",
    "FileReadResult": ".types",
    "FileReplaceResult": ".types",
    "FileSearchResult": ".types",
    "FileUploadResult": ".types",
    "FileWriteResult": ".types",
    "GlobFileInfo": ".types",
    "GrepMatch": ".types",
    "HotkeyAction": ".types",
    "HttpValidationError": ".types",
    "Icon": ".types",
    "ImageContent": ".types",
    "JupyterCreateSessionResponse": ".types",
    "JupyterExecuteResponse": ".types",
    "JupyterInfoResponse": ".types",
    "JupyterOutput": ".types",
    "KeyDownAction": ".types",
    "KeyUpAction": ".types",
    "Language": ".types",
    "ListToolsResult": ".types",
    "Mode": ".types",
    "MouseDownAction": ".types",
    "MouseUpAction": ".types",
    "MoveRelAction": ".types",
    "MoveToAction": ".types",
    "NavigateRequestWaitUntil": ".browser_page",
    "NodeJsCreateSessionResponse": ".types",
    "NodeJsDeleteSessionResponse": ".types",
    "NodeJsExecuteResponse": ".types",
    "NodeJsOutput": ".types",
    "NodeJsPackageInfo": ".types",
    "NodeJsRuntimeInfo": ".types",
    "NodeJsSessionInfo": ".types",
    "NodeJsSessionListResponse": ".types",
    "NodeJsSessionResponse": ".types",
    "NodeJsUpdateSessionResponse": ".types",
    "PressAction": ".types",
    "ProxyBypassRequest": ".types",
    "ProxyDiagnoseResult": ".types",
    "ProxyMappingRoute": ".types",
    "ProxyUpstreamInfo": ".types",
    "RecordRequestAction": ".browser_page",
    "Resolution": ".types",
    "Resource": ".types",
    "ResourceLink": ".types",
    "Response": ".types",
    "ResponseActiveSessionsResult": ".types",
    "ResponseActiveShellSessionsResult": ".types",
    "ResponseBashExecResult": ".types",
    "ResponseBashOutputResult": ".types",
    "ResponseBashSessionInfo": ".types",
    "ResponseBrowserInfoResult": ".types",
    "ResponseCallToolResultModel": ".types",
    "ResponseCallToolResultModelDataContentItem": ".types",
    "ResponseCallToolResultModelDataContentItem_Audio": ".types",
    "ResponseCallToolResultModelDataContentItem_Image": ".types",
    "ResponseCallToolResultModelDataContentItem_Resource": ".types",
    "ResponseCallToolResultModelDataContentItem_ResourceLink": ".types",
    "ResponseCallToolResultModelDataContentItem_Text": ".types",
    "ResponseCaptchaWaitResult": ".types",
    "ResponseCodeExecuteResponse": ".types",
    "ResponseCodeInfoResponse": ".types",
    "ResponseDict": ".types",
    "ResponseFileFindResult": ".types",
    "ResponseFileGlobResult": ".types",
    "ResponseFileGrepResult": ".types",
    "ResponseFileListResult": ".types",
    "ResponseFileReadResult": ".types",
    "ResponseFileReplaceResult": ".types",
    "ResponseFileSearchResult": ".types",
    "ResponseFileUploadResult": ".types",
    "ResponseFileWriteResult": ".types",
    "ResponseJupyterCreateSessionResponse": ".types",
    "ResponseJupyterExecuteResponse": ".types",
    "ResponseJupyterInfoResponse": ".types",
    "ResponseList": ".types",
    "ResponseListBashSessionInfo": ".types",
    "ResponseListProxyMappingRoute": ".types",
    "ResponseListStr": ".types",
    "ResponseListToolsResultModel": ".types",
    "ResponseNodeJsCreateSessionResponse": ".types",
    "ResponseNodeJsDeleteSessionResponse": ".types",
    "ResponseNodeJsExecuteResponse": ".types",
    "ResponseNodeJsRuntimeInfo": ".types",
    "ResponseNodeJsSessionListResponse": ".types",
    "ResponseNodeJsSessionResponse": ".types",
    "ResponseNodeJsUpdateSessionResponse": ".types",
    "ResponseProxyDiagnoseResult": ".types",
    "ResponseProxyMappingRoute": ".types",
    "ResponseProxyUpstreamInfo": ".types",
    "ResponseShellCommandResult": ".types",
    "ResponseShellCreateSessionResponse": ".types",
    "ResponseShellKillResult": ".types",
    "ResponseShellViewResult": ".types",
    "ResponseShellWaitResult": ".types",
    "ResponseShellWriteResult": ".types",
    "ResponseSkillContentResult": ".types",
    "ResponseSkillMetadata": ".types",
    "ResponseSkillMetadataCollection": ".types",
    "ResponseSkillRegistrationResult": ".types",
    "ResponseStr": ".types",
    "ResponseStrReplaceEditorResult": ".types",
    "ResponseUnionProxyUpstreamInfoNoneType": ".types",
    "RestartRequest": ".types",
    "RightClickAction": ".types",
    "RouteResponseModel": ".types",
    "RuntimeEnv": ".types",
    "Sandbox": ".client",
    "SandboxDetail": ".types",
    "SandboxResponse": ".types",
    "ScrollAction": ".types",
    "SessionInfo": ".types",
    "SessionStatus": ".types",
    "ShellCommandResult": ".types",
    "ShellCreateSessionResponse": ".types",
    "ShellKillResult": ".types",
    "ShellSessionInfo": ".types",
    "ShellViewResult": ".types",
    "ShellWaitResult": ".types",
    "ShellWriteResult": ".types",
    "SkillContentResult": ".types",
    "SkillMetadata": ".types",
    "SkillMetadataCollection": ".types",
    "SkillRegistrationResult": ".types",
    "StrReplaceEditorRequestReplaceMode": ".file",
    "StrReplaceEditorResult": ".types",
    "SystemEnv": ".types",
    "TextContent": ".types",
    "TextResourceContents": ".types",
    "Tool": ".types",
    "ToolAnnotations": ".types",
    "ToolCategory": ".types",
    "ToolExecution": ".types",
    "ToolExecutionTaskSupport": ".types",
    "ToolSpec": ".types",
    "Type": ".browser_page",
    "TypingAction": ".types",
    "UnprocessableEntityError": ".errors",
    "ValidationError": ".types",
    "ValidationErrorLocItem": ".types",
    "WaitAction": ".types",
    "auth": ".",
    "bash": ".",
    "browser": ".",
    "browser_captcha": ".",
    "browser_cookies": ".",
    "browser_network": ".",
    "browser_page": ".",
    "browser_state": ".",
    "browser_tabs": ".",
    "code": ".",
    "file": ".",
    "jupyter": ".",
    "mcp": ".",
    "nodejs": ".",
    "proxy": ".",
    "sandbox": ".",
    "shell": ".",
    "skills": ".",
    "util": ".",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "Action",
    "ActionData",
    "ActionResponse",
    "Action_Click",
    "Action_DoubleClick",
    "Action_DragRel",
    "Action_DragTo",
    "Action_Hotkey",
    "Action_KeyDown",
    "Action_KeyUp",
    "Action_MouseDown",
    "Action_MouseUp",
    "Action_MoveRel",
    "Action_MoveTo",
    "Action_Press",
    "Action_RightClick",
    "Action_Scroll",
    "Action_Typing",
    "Action_Wait",
    "ActiveSessionsResult",
    "ActiveShellSessionsResult",
    "Annotations",
    "AnnotationsAudienceItem",
    "AsyncSandbox",
    "AudioContent",
    "AvailableTool",
    "BashCommandInfo",
    "BashCommandStatus",
    "BashExecResult",
    "BashOutputResult",
    "BashSessionInfo",
    "BlobResourceContents",
    "BrowserInfoResult",
    "BrowserViewport",
    "Button",
    "CallToolResult",
    "CaptchaWaitResult",
    "CheckRequest",
    "ClickAction",
    "CodeExecuteResponse",
    "CodeInfoResponse",
    "CodeLanguageInfo",
    "Command",
    "CommandStatus",
    "ConsoleRecord",
    "DependencyCommandResult",
    "DoubleClickAction",
    "DragRelAction",
    "DragToAction",
    "EmbeddedResource",
    "FileContentEncoding",
    "FileFindResult",
    "FileGlobResult",
    "FileGrepResult",
    "FileInfo",
    "FileListResult",
    "FileReadResult",
    "FileReplaceResult",
    "FileSearchResult",
    "FileUploadResult",
    "FileWriteResult",
    "GlobFileInfo",
    "GrepMatch",
    "HotkeyAction",
    "HttpValidationError",
    "Icon",
    "ImageContent",
    "JupyterCreateSessionResponse",
    "JupyterExecuteResponse",
    "JupyterInfoResponse",
    "JupyterOutput",
    "KeyDownAction",
    "KeyUpAction",
    "Language",
    "ListToolsResult",
    "Mode",
    "MouseDownAction",
    "MouseUpAction",
    "MoveRelAction",
    "MoveToAction",
    "NavigateRequestWaitUntil",
    "NodeJsCreateSessionResponse",
    "NodeJsDeleteSessionResponse",
    "NodeJsExecuteResponse",
    "NodeJsOutput",
    "NodeJsPackageInfo",
    "NodeJsRuntimeInfo",
    "NodeJsSessionInfo",
    "NodeJsSessionListResponse",
    "NodeJsSessionResponse",
    "NodeJsUpdateSessionResponse",
    "PressAction",
    "ProxyBypassRequest",
    "ProxyDiagnoseResult",
    "ProxyMappingRoute",
    "ProxyUpstreamInfo",
    "RecordRequestAction",
    "Resolution",
    "Resource",
    "ResourceLink",
    "Response",
    "ResponseActiveSessionsResult",
    "ResponseActiveShellSessionsResult",
    "ResponseBashExecResult",
    "ResponseBashOutputResult",
    "ResponseBashSessionInfo",
    "ResponseBrowserInfoResult",
    "ResponseCallToolResultModel",
    "ResponseCallToolResultModelDataContentItem",
    "ResponseCallToolResultModelDataContentItem_Audio",
    "ResponseCallToolResultModelDataContentItem_Image",
    "ResponseCallToolResultModelDataContentItem_Resource",
    "ResponseCallToolResultModelDataContentItem_ResourceLink",
    "ResponseCallToolResultModelDataContentItem_Text",
    "ResponseCaptchaWaitResult",
    "ResponseCodeExecuteResponse",
    "ResponseCodeInfoResponse",
    "ResponseDict",
    "ResponseFileFindResult",
    "ResponseFileGlobResult",
    "ResponseFileGrepResult",
    "ResponseFileListResult",
    "ResponseFileReadResult",
    "ResponseFileReplaceResult",
    "ResponseFileSearchResult",
    "ResponseFileUploadResult",
    "ResponseFileWriteResult",
    "ResponseJupyterCreateSessionResponse",
    "ResponseJupyterExecuteResponse",
    "ResponseJupyterInfoResponse",
    "ResponseList",
    "ResponseListBashSessionInfo",
    "ResponseListProxyMappingRoute",
    "ResponseListStr",
    "ResponseListToolsResultModel",
    "ResponseNodeJsCreateSessionResponse",
    "ResponseNodeJsDeleteSessionResponse",
    "ResponseNodeJsExecuteResponse",
    "ResponseNodeJsRuntimeInfo",
    "ResponseNodeJsSessionListResponse",
    "ResponseNodeJsSessionResponse",
    "ResponseNodeJsUpdateSessionResponse",
    "ResponseProxyDiagnoseResult",
    "ResponseProxyMappingRoute",
    "ResponseProxyUpstreamInfo",
    "ResponseShellCommandResult",
    "ResponseShellCreateSessionResponse",
    "ResponseShellKillResult",
    "ResponseShellViewResult",
    "ResponseShellWaitResult",
    "ResponseShellWriteResult",
    "ResponseSkillContentResult",
    "ResponseSkillMetadata",
    "ResponseSkillMetadataCollection",
    "ResponseSkillRegistrationResult",
    "ResponseStr",
    "ResponseStrReplaceEditorResult",
    "ResponseUnionProxyUpstreamInfoNoneType",
    "RestartRequest",
    "RightClickAction",
    "RouteResponseModel",
    "RuntimeEnv",
    "Sandbox",
    "SandboxDetail",
    "SandboxResponse",
    "ScrollAction",
    "SessionInfo",
    "SessionStatus",
    "ShellCommandResult",
    "ShellCreateSessionResponse",
    "ShellKillResult",
    "ShellSessionInfo",
    "ShellViewResult",
    "ShellWaitResult",
    "ShellWriteResult",
    "SkillContentResult",
    "SkillMetadata",
    "SkillMetadataCollection",
    "SkillRegistrationResult",
    "StrReplaceEditorRequestReplaceMode",
    "StrReplaceEditorResult",
    "SystemEnv",
    "TextContent",
    "TextResourceContents",
    "Tool",
    "ToolAnnotations",
    "ToolCategory",
    "ToolExecution",
    "ToolExecutionTaskSupport",
    "ToolSpec",
    "Type",
    "TypingAction",
    "UnprocessableEntityError",
    "ValidationError",
    "ValidationErrorLocItem",
    "WaitAction",
    "auth",
    "bash",
    "browser",
    "browser_captcha",
    "browser_cookies",
    "browser_network",
    "browser_page",
    "browser_state",
    "browser_tabs",
    "code",
    "file",
    "jupyter",
    "mcp",
    "nodejs",
    "proxy",
    "sandbox",
    "shell",
    "skills",
    "util",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.response import Response
from ..types.response_captcha_wait_result import ResponseCaptchaWaitResult
from .raw_client import AsyncRawBrowserCaptchaClient, RawBrowserCaptchaClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class BrowserCaptchaClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawBrowserCaptchaClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawBrowserCaptchaClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawBrowserCaptchaClient
        """
        return self._raw_client

    def detect(self, *, request_options: typing.Optional[RequestOptions] = None) -> Response:
        """
        Detect CAPTCHA on the current page.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Response
            Successful Response

        Examples
        --------
        from agent_sandbox import Sandbox

        client = Sandbox(
            base_url="https://yourhost.com/path/to/api",
        )
        client.browser_captcha.detect()
        """
        _response = self._raw_client.detect(request_options=request_options)
        return _response.data

    def wait(
        self,
        *,
        timeout: typing.Optional[float] = OMIT,
        poll_interval: typing.Optional[float] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ResponseCaptchaWaitResult:
        """
        Wait for CAPTCHA to be resolved.

        Parameters
        ----------
        timeout : typing.Optional[float]

        poll_interval : typing.Optional[float]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResponseCaptchaWaitResult
            Successful Response

        Examples
        --------
        from agent_sandbox import Sandbox

        client = Sandbox(
            base_url="https://yourhost.com/path/to/api",
        )
        client.browser_captcha.wait()
        """
        _response = self._raw_client.wait(timeout=timeout, poll_interval=poll_interval, request_options=request_options)
        return _response.data


class AsyncBrowserCaptchaClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawBrowserCaptchaClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawBrowserCaptchaClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawBrowserCaptchaClient
        """
        return self._raw_client

    async def detect(self, *, request_options: typing.Optional[RequestOptions] = None) -> Response:
        """
        Detect CAPTCHA on the current page.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Response
            Successful Response

        Examples
        --------
        import asyncio

        from agent_sandbox import AsyncSandbox

        client = AsyncSandbox(
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.browser_captcha.detect()


        asyncio.run(main())
        """
        _response = await self._raw_client.detect(request_options=request_options)
        return _response.data

    async def wait(
        self,
        *,
        timeout: typing.Optional[float] = OMIT,
        poll_interval: typing.Optional[float] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ResponseCaptchaWaitResult:
        """
        Wait for CAPTCHA to be resolved.

        Parameters
        ----------
        timeout : typing.Optional[float]

        poll_interval : typing.Optional[float]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResponseCaptchaWaitResult
            Successful Response

        Examples
        --------
        import asyncio

        from agent_sandbox import AsyncSandbox

        client = AsyncSandbox(
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.browser_captcha.wait()


        asyncio.run(main())
        """
        _response = await self._raw_client.wait(
            timeout=timeout, poll_interval=poll_interval, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .language import Language


class CodeLanguageInfo(UniversalBaseModel):
    """
    Metadata about a supported code runtime
    """

    language: Language = pydantic.Field()
    """
    Supported language identifier
    """

    description: str = pydantic.Field()
    """
    Human readable runtime description
    """

    runtime_version: typing.Optional[str] = pydantic.Field(default=None)
    """
    Primary runtime version identifier
    """

    default_timeout: typing.Optional[int] = pydantic.Field(default=None)
    """
    Default timeout in seconds
    """

    max_timeout: typing.Optional[int] = pydantic.Field(default=None)
    """
    Maximum allowed timeout in seconds
    """

    details: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Additional runtime specific metadata
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .command_status import CommandStatus


class BashExecResult(UniversalBaseModel):
    """
    Result of exec_command — returned by POST /v1/bash/exec.
    """

    session_id: str = pydantic.Field()
    """
    Session identifier
    """

    command_id: str = pydantic.Field()
    """
    Unique command identifier
    """

    command: str = pydantic.Field()
    """
    The executed command
    """

    status: CommandStatus = pydantic.Field()
    """
    Command status
    """

    stdout: typing.Optional[str] = pydantic.Field(default=None)
    """
    Stdout output up to this point
    """

    stderr: typing.Optional[str] = pydantic.Field(default=None)
    """
    Stderr output up to this point
    """

    exit_code: typing.Optional[int] = pydantic.Field(default=None)
    """
    Exit code (when completed)
    """

    offset: typing.Optional[int] = pydantic.Field(default=None)
    """
    Current stdout offset for subsequent /output calls
    """

    stderr_offset: typing.Optional[int] = pydantic.Field(default=None)
    """
    Current stderr offset
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .action_data import ActionData
    from .action_response import ActionResponse
    from .active_sessions_result import ActiveSessionsResult
    from .active_shell_sessions_result import ActiveShellSessionsResult
    from .annotations import Annotations
    from .annotations_audience_item import AnnotationsAudienceItem
    from .audio_content import AudioContent
    from .available_tool import AvailableTool
    from .bash_command_info import BashCommandInfo
    from .bash_command_status import BashCommandStatus
    from .bash_exec_result import BashExecResult
    from .bash_output_result import BashOutputResult
    from .bash_session_info import BashSessionInfo
    from .blob_resource_contents import BlobResourceContents
    from .browser_info_result import BrowserInfoResult
    from .browser_viewport import BrowserViewport
    from .button import Button
    from .call_tool_result import CallToolResult
    from .captcha_wait_result import CaptchaWaitResult
    from .check_request import CheckRequest
    from .click_action import ClickAction
    from .code_execute_response import CodeExecuteResponse
    from .code_info_response import CodeInfoResponse
    from .code_language_info import CodeLanguageInfo
    from .command_status import CommandStatus
    from .console_record import ConsoleRecord
    from .dependency_command_result import DependencyCommandResult
    from .double_click_action import DoubleClickAction
    from .drag_rel_action import DragRelAction
    from .drag_to_action import DragToAction
    from .embedded_resource import EmbeddedResource
    from .file_content_encoding import FileContentEncoding
    from .file_find_result import FileFindResult
    from .file_glob_result import FileGlobResult
    from .file_grep_result import FileGrepResult
    from .file_info import FileInfo
    from .file_list_result import FileListResult
    from .file_read_result import FileReadResult
    from .file_replace_result import FileReplaceResult
    from .file_search_result import FileSearchResult
    from .file_upload_result import FileUploadResult
    from .file_write_result import FileWriteResult
    from .glob_file_info import GlobFileInfo
    from .grep_match import GrepMatch
    from .hotkey_action import HotkeyAction
    from .http_validation_error import HttpValidationError
    from .icon import Icon
    from .image_content import ImageContent
    from .jupyter_create_session_response import JupyterCreateSessionResponse
    from .jupyter_execute_response import JupyterExecuteResponse
    from .jupyter_info_response import JupyterInfoResponse
    from .jupyter_output import JupyterOutput
    from .key_down_action import KeyDownAction
    from .key_up_action import KeyUpAction
    from .language import Language
    from .list_tools_result import ListToolsResult
    from .mode import Mode
    from .mouse_down_action import MouseDownAction
    from .mouse_up_action import MouseUpAction
    from .move_rel_action import MoveRelAction
    from .move_to_action import MoveToAction
    from .node_js_create_session_response import NodeJsCreateSessionResponse
    from .node_js_delete_session_response import NodeJsDeleteSessionResponse
    from .node_js_execute_response import NodeJsExecuteResponse
    from .node_js_output import NodeJsOutput
    from .node_js_package_info import NodeJsPackageInfo
    from .node_js_runtime_info import NodeJsRuntimeInfo
    from .node_js_session_info import NodeJsSessionInfo
    from .node_js_session_list_response import NodeJsSessionListResponse
    from .node_js_session_response import NodeJsSessionResponse
    from .node_js_update_session_response import NodeJsUpdateSessionResponse
    from .press_action import PressAction
    from .proxy_bypass_request import ProxyBypassRequest
    from .proxy_diagnose_result import ProxyDiagnoseResult
    from .proxy_mapping_route import ProxyMappingRoute
    from .proxy_upstream_info import ProxyUpstreamInfo
    from .resolution import Resolution
    from .resource import Resource
    from .resource_link import ResourceLink
    from .response import Response
    from .response_active_sessions_result import ResponseActiveSessionsResult
    from .response_active_shell_sessions_result import ResponseActiveShellSessionsResult
    from .response_bash_exec_result import ResponseBashExecResult
    from .response_bash_output_result import ResponseBashOutputResult
    from .response_bash_session_info import ResponseBashSessionInfo
    from .response_browser_info_result import ResponseBrowserInfoResult
    from .response_call_tool_result_model import ResponseCallToolResultModel
    from .response_call_tool_result_model_data_content_item import (
        ResponseCallToolResultModelDataContentItem,
        ResponseCallToolResultModelDataContentItem_Audio,
        ResponseCallToolResultModelDataContentItem_Image,
        ResponseCallToolResultModelDataContentItem_Resource,
        ResponseCallToolResultModelDataContentItem_ResourceLink,
        ResponseCallToolResultModelDataContentItem_Text,
    )
    from .response_captcha_wait_result import ResponseCaptchaWaitResult
    from .response_code_execute_response import ResponseCodeExecuteResponse
    from .response_code_info_response import ResponseCodeInfoResponse
    from .response_dict import ResponseDict
    from .response_file_find_result import ResponseFileFindResult
    from .response_file_glob_result import ResponseFileGlobResult
    from .response_file_grep_result import ResponseFileGrepResult
    from .response_file_list_result import ResponseFileListResult
    from .response_file_read_result import ResponseFileReadResult
    from .response_file_replace_result import ResponseFileReplaceResult
    from .response_file_search_result import ResponseFileSearchResult
    from .response_file_upload_result import ResponseFileUploadResult
    from .response_file_write_result import ResponseFileWriteResult
    from .response_jupyter_create_session_response import ResponseJupyterCreateSessionResponse
    from .response_jupyter_execute_response import ResponseJupyterExecuteResponse
    from .response_jupyter_info_response import ResponseJupyterInfoResponse
    from .response_list import ResponseList
    from .response_list_bash_session_info import ResponseListBashSessionInfo
    from .response_list_proxy_mapping_route import ResponseListProxyMappingRoute
    from .response_list_str import ResponseListStr
    from .response_list_tools_result_model import ResponseListToolsResultModel
    from .response_node_js_create_session_response import ResponseNodeJsCreateSessionResponse
    from .response_node_js_delete_session_response import ResponseNodeJsDeleteSessionResponse
    from .response_node_js_execute_response import ResponseNodeJsExecuteResponse
    from .response_node_js_runtime_info import ResponseNodeJsRuntimeInfo
    from .response_node_js_session_list_response import ResponseNodeJsSessionListResponse
    from .response_node_js_session_response import ResponseNodeJsSessionResponse
    from .response_node_js_update_session_response import ResponseNodeJsUpdateSessionResponse
    from .response_proxy_diagnose_result import ResponseProxyDiagnoseResult
    from .response_proxy_mapping_route import ResponseProxyMappingRoute
    from .response_proxy_upstream_info import ResponseProxyUpstreamInfo
    from .response_shell_command_result import ResponseShellCommandResult
    from .response_shell_create_session_response import ResponseShellCreateSessionResponse
    from .response_shell_kill_result import ResponseShellKillResult
    from .response_shell_view_result import ResponseShellViewResult
    from .response_shell_wait_result import ResponseShellWaitResult
    from .response_shell_write_result import ResponseShellWriteResult
    from .response_skill_content_result import ResponseSkillContentResult
    from .response_skill_metadata import ResponseSkillMetadata
    from .response_skill_metadata_collection import ResponseSkillMetadataCollection
    from .response_skill_registration_result import ResponseSkillRegistrationResult
    from .response_str import ResponseStr
    from .response_str_replace_editor_result import ResponseStrReplaceEditorResult
    from .response_union_proxy_upstream_info_none_type import ResponseUnionProxyUpstreamInfoNoneType
    from .restart_request import RestartRequest
    from .right_click_action import RightClickAction
    from .route_response_model import RouteResponseModel
    from .runtime_env import RuntimeEnv
    from .sandbox_detail import SandboxDetail
    from .sandbox_response import SandboxResponse
    from .scroll_action import ScrollAction
    from .session_info import SessionInfo
    from .session_status import SessionStatus
    from .shell_command_result import ShellCommandResult
    from .shell_create_session_response import ShellCreateSessionResponse
    from .shell_kill_result import ShellKillResult
    from .shell_session_info import ShellSessionInfo
    from .shell_view_result import ShellViewResult
    from .shell_wait_result import ShellWaitResult
    from .shell_write_result import ShellWriteResult
    from .skill_content_result import SkillContentResult
    from .skill_metadata import SkillMetadata
    from .skill_metadata_collection import SkillMetadataCollection
    from .skill_registration_result import SkillRegistrationResult
    from .str_replace_editor_result import StrReplaceEditorResult
    from .system_env import SystemEnv
    from .text_content import TextContent
    from .text_resource_contents import TextResourceContents
    from .tool import Tool
    from .tool_annotations import ToolAnnotations
    from .tool_category import ToolCategory
    from .tool_execution import ToolExecution
    from .tool_execution_task_support import ToolExecutionTaskSupport
    from .tool_spec import ToolSpec
    from .typing_action import TypingAction
    from .validation_error import ValidationError
    from .validation_error_loc_item import ValidationErrorLocItem
    from .wait_action import WaitAction
_dynamic_imports: typing.Dict[str, str] = {
    "ActionData": ".action_data",
    "ActionResponse": ".action_response",
    "ActiveSessionsResult": ".active_sessions_result",
    "ActiveShellSessionsResult": ".active_shell_sessions_result",
    "Annotations": ".annotations",
    "AnnotationsAudienceItem": ".annotations_audience_item",
    "AudioContent": ".audio_content",
    "AvailableTool": ".available_tool",
    "BashCommandInfo": ".bash_command_info",
    "BashCommandStatus": ".bash_command_status",
    "BashExecResult": ".bash_exec_result",
    "BashOutputResult": ".bash_output_result",
    "BashSessionInfo": ".bash_session_info",
    "BlobResourceContents": ".blob_resource_contents",
    "BrowserInfoResult": ".browser_info_result",
    "BrowserViewport": ".browser_viewport",
    "Button": ".button",
    "CallToolResult": ".call_tool_result",
    "CaptchaWaitResult": ".captcha_wait_result",
    "CheckRequest": ".check_request",
    "ClickAction": ".click_action",
    "CodeExecuteResponse": ".code_execute_response",
    "CodeInfoResponse": ".code_info_response",
    "CodeLanguageInfo": ".code_language_info",
    "CommandStatus": ".command_status",
    "ConsoleRecord": ".console_record",
    "DependencyCommandResult": ".dependency_command_result",
    "DoubleClickAction": ".double_click_action",
    "DragRelAction": ".drag_rel_action",
    "DragToAction": ".drag_to_action",
    "EmbeddedResource": ".embedded_resource",
    "FileContentEncoding": ".file_content_encoding",
    "FileFindResult": ".file_find_result",
    "FileGlobResult": ".file_glob_result",
    "FileGrepResult": ".file_grep_result",
    "FileInfo": ".file_info",
    "FileListResult": ".file_list_result",
    "FileReadResult": ".file_read_result",
    "FileReplaceResult": ".file_replace_result",
    "FileSearchResult": ".file_search_result",
    "FileUploadResult": ".file_upload_result",
    "FileWriteResult": ".file_write_result",
    "GlobFileInfo": ".glob_file_info",
    "GrepMatch": ".grep_match",
    "HotkeyAction": ".hotkey_action",
    "HttpValidationError": ".http_validation_error",
    "Icon": ".icon",
    "ImageContent": ".image_content",
    "JupyterCreateSessionResponse": ".jupyter_create_session_response",
    "JupyterExecuteResponse": ".jupyter_execute_response",
    "JupyterInfoResponse": ".jupyter_info_response",
    "JupyterOutput": ".jupyter_output",
    "KeyDownAction": ".key_down_action",
    "KeyUpAction": ".key_up_action",
    "Language": ".language",
    "ListToolsResult": ".list_tools_result",
    "Mode": ".mode",
    "MouseDownAction": ".mouse_down_action",
    "MouseUpAction": ".mouse_up_action",
    "MoveRelAction": ".move_rel_action",
    "MoveToAction": ".move_to_action",
    "NodeJsCreateSessionResponse": ".node_js_create_session_response",
    "NodeJsDeleteSessionResponse": ".node_js_delete_session_response",
    "NodeJsExecuteResponse": ".node_js_execute_response",
    "NodeJsOutput": ".node_js_output",
    "NodeJsPackageInfo": ".node_js_package_info",
    "NodeJsRuntimeInfo": ".node_js_runtime_info",
    "NodeJsSessionInfo": ".node_js_session_info",
    "NodeJsSessionListResponse": ".node_js_session_list_response",
    "NodeJsSessionResponse": ".node_js_session_response",
    "NodeJsUpdateSessionResponse": ".node_js_update_session_response",
    "PressAction": ".press_action",
    "ProxyBypassRequest": ".proxy_bypass_request",
    "ProxyDiagnoseResult": ".proxy_diagnose_result",
    "ProxyMappingRoute": ".proxy_mapping_route",
    "ProxyUpstreamInfo": ".proxy_upstream_info",
    "Resolution": ".resolution",
    "Resource": ".resource",
    "ResourceLink": ".resource_link",
    "Response": ".response",
    "ResponseActiveSessionsResult": ".response_active_sessions_result",
    "ResponseActiveShellSessionsResult": ".response_active_shell_sessions_result",
    "ResponseBashExecResult": ".response_bash_exec_result",
    "ResponseBashOutputResult": ".response_bash_output_result",
    "ResponseBashSessionInfo": ".response_bash_session_info",
    "ResponseBrowserInfoResult": ".response_browser_info_result",
    "ResponseCallToolResultModel": ".response_call_tool_result_model",
    "ResponseCallToolResultModelDataContentItem": ".response_call_tool_result_model_data_content_item",
    "ResponseCallToolResultModelDataContentItem_Audio": ".response_call_tool_result_model_data_content_item",
    "ResponseCallToolResultModelDataContentItem_Image": ".response_call_tool_result_model_data_content_item",
    "ResponseCallToolResultModelDataContentItem_Resource": ".response_call_tool_result_model_data_content_item",
    "ResponseCallToolResultModelDataContentItem_ResourceLink": ".response_call_tool_result_model_data_content_item",
    "ResponseCallToolResultModelDataContentItem_Text": ".response_call_tool_result_model_data_content_item",
    "ResponseCaptchaWaitResult": ".response_captcha_wait_result",
    "ResponseCodeExecuteResponse": ".response_code_execute_response",
    "ResponseCodeInfoResponse": ".response_code_info_response",
    "ResponseDict": ".response_dict",
    "ResponseFileFindResult": ".response_file_find_result",
    "ResponseFileGlobResult": ".response_file_glob_result",
    "ResponseFileGrepResult": ".response_file_grep_result",
    "ResponseFileListResult": ".response_file_list_result",
    "ResponseFileReadResult": ".response_file_read_result",
    "ResponseFileReplaceResult": ".response_file_replace_result",
    "ResponseFileSearchResult": ".response_file_search_result",
    "ResponseFileUploadResult": ".response_file_upload_result",
    "ResponseFileWriteResult": ".response_file_write_result",
    "ResponseJupyterCreateSessionResponse": ".response_jupyter_create_session_response",
    "ResponseJupyterExecuteResponse": ".response_jupyter_execute_response",
    "ResponseJupyterInfoResponse": ".response_jupyter_info_response",
    "ResponseList": ".response_list",
    "ResponseListBashSessionInfo": ".response_list_bash_session_info",
    "ResponseListProxyMappingRoute": ".response_list_proxy_mapping_route",
    "ResponseListStr": ".response_list_str",
    "ResponseListToolsResultModel": ".response_list_tools_result_model",
    "ResponseNodeJsCreateSessionResponse": ".response_node_js_create_session_response",
    "ResponseNodeJsDeleteSessionResponse": ".response_node_js_delete_session_response",
    "ResponseNodeJsExecuteResponse": ".response_node_js_execute_response",
    "ResponseNodeJsRuntimeInfo": ".response_node_js_runtime_info",
    "ResponseNodeJsSessionListResponse": ".response_node_js_session_list_response",
    "ResponseNodeJsSessionResponse": ".response_node_js_session_response",
    "ResponseNodeJsUpdateSessionResponse": ".response_node_js_update_session_response",
    "ResponseProxyDiagnoseResult": ".response_proxy_diagnose_result",
    "ResponseProxyMappingRoute": ".response_proxy_mapping_route",
    "ResponseProxyUpstreamInfo": ".response_proxy_upstream_info",
    "ResponseShellCommandResult": ".response_shell_command_result",
    "ResponseShellCreateSessionResponse": ".response_shell_create_session_response",
    "ResponseShellKillResult": ".response_shell_kill_result",
    "ResponseShellViewResult": ".response_shell_view_result",
    "ResponseShellWaitResult": ".response_shell_wait_result",
    "ResponseShellWriteResult": ".response_shell_write_result",
    "ResponseSkillContentResult": ".response_skill_content_result",
    "ResponseSkillMetadata": ".response_skill_metadata",
    "ResponseSkillMetadataCollection": ".response_skill_metadata_collection",
    "ResponseSkillRegistrationResult": ".response_skill_registration_result",
    "ResponseStr": ".response_str",
    "ResponseStrReplaceEditorResult": ".response_str_replace_editor_result",
    "ResponseUnionProxyUpstreamInfoNoneType": ".response_union_proxy_upstream_info_none_type",
    "RestartRequest": ".restart_request",
    "RightClickAction": ".right_click_action",
    "RouteResponseModel": ".route_response_model",
    "RuntimeEnv": ".runtime_env",
    "SandboxDetail": ".sandbox_detail",
    "SandboxResponse": ".sandbox_response",
    "ScrollAction": ".scroll_action",
    "SessionInfo": ".session_info",
    "SessionStatus": ".session_status",
    "ShellCommandResult": ".shell_command_result",
    "ShellCreateSessionResponse": ".shell_create_session_response",
    "ShellKillResult": ".shell_kill_result",
    "ShellSessionInfo": ".shell_session_info",
    "ShellViewResult": ".shell_view_result",
    "ShellWaitResult": ".shell_wait_result",
    "ShellWriteResult": ".shell_write_result",
    "SkillContentResult": ".skill_content_result",
    "SkillMetadata": ".skill_metadata",
    "SkillMetadataCollection": ".skill_metadata_collection",
    "SkillRegistrationResult": ".skill_registration_result",
    "StrReplaceEditorResult": ".str_replace_editor_result",
    "SystemEnv": ".system_env",
    "TextContent": ".text_content",
    "TextResourceContents": ".text_resource_contents",
    "Tool": ".tool",
    "ToolAnnotations": ".tool_annotations",
    "ToolCategory": ".tool_category",
    "ToolExecution": ".tool_execution",
    "ToolExecutionTaskSupport": ".tool_execution_task_support",
    "ToolSpec": ".tool_spec",
    "TypingAction": ".typing_action",
    "ValidationError": ".validation_error",
    "ValidationErrorLocItem": ".validation_error_loc_item",
    "WaitAction": ".wait_action",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ActionData",
    "ActionResponse",
    "ActiveSessionsResult",
    "ActiveShellSessionsResult",
    "Annotations",
    "AnnotationsAudienceItem",
    "AudioContent",
    "AvailableTool",
    "BashCommandInfo",
    "BashCommandStatus",
    "BashExecResult",
    "BashOutputResult",
    "BashSessionInfo",
    "BlobResourceContents",
    "BrowserInfoResult",
    "BrowserViewport",
    "Button",
    "CallToolResult",
    "CaptchaWaitResult",
    "CheckRequest",
    "ClickAction",
    "CodeExecuteResponse",
    "CodeInfoResponse",
    "CodeLanguageInfo",
    "CommandStatus",
    "ConsoleRecord",
    "DependencyCommandResult",
    "DoubleClickAction",
    "DragRelAction",
    "DragToAction",
    "EmbeddedResource",
    "FileContentEncoding",
    "FileFindResult",
    "FileGlobResult",
    "FileGrepResult",
    "FileInfo",
    "FileListResult",
    "FileReadResult",
    "FileReplaceResult",
    "FileSearchResult",
    "FileUploadResult",
    "FileWriteResult",
    "GlobFileInfo",
    "GrepMatch",
    "HotkeyAction",
    "HttpValidationError",
    "Icon",
    "ImageContent",
    "JupyterCreateSessionResponse",
    "JupyterExecuteResponse",
    "JupyterInfoResponse",
    "JupyterOutput",
    "KeyDownAction",
    "KeyUpAction",
    "Language",
    "ListToolsResult",
    "Mode",
    "MouseDownAction",
    "MouseUpAction",
    "MoveRelAction",
    "MoveToAction",
    "NodeJsCreateSessionResponse",
    "NodeJsDeleteSessionResponse",
    "NodeJsExecuteResponse",
    "NodeJsOutput",
    "NodeJsPackageInfo",
    "NodeJsRuntimeInfo",
    "NodeJsSessionInfo",
    "NodeJsSessionListResponse",
    "NodeJsSessionResponse",
    "NodeJsUpdateSessionResponse",
    "PressAction",
    "ProxyBypassRequest",
    "ProxyDiagnoseResult",
    "ProxyMappingRoute",
    "ProxyUpstreamInfo",
    "Resolution",
    "Resource",
    "ResourceLink",
    "Response",
    "ResponseActiveSessionsResult",
    "ResponseActiveShellSessionsResult",
    "ResponseBashExecResult",
    "ResponseBashOutputResult",
    "ResponseBashSessionInfo",
    "ResponseBrowserInfoResult",
    "ResponseCallToolResultModel",
    "ResponseCallToolResultModelDataContentItem",
    "ResponseCallToolResultModelDataContentItem_Audio",
    "ResponseCallToolResultModelDataContentItem_Image",
    "ResponseCallToolResultModelDataContentItem_Resource",
    "ResponseCallToolResultModelDataContentItem_ResourceLink",
    "ResponseCallToolResultModelDataContentItem_Text",
    "ResponseCaptchaWaitResult",
    "ResponseCodeExecuteResponse",
    "ResponseCodeInfoResponse",
    "ResponseDict",
    "ResponseFileFindResult",
    "ResponseFileGlobResult",
    "ResponseFileGrepResult",
    "ResponseFileListResult",
    "ResponseFileReadResult",
    "ResponseFileReplaceResult",
    "ResponseFileSearchResult",
    "ResponseFileUploadResult",
    "ResponseFileWriteResult",
    "ResponseJupyterCreateSessionResponse",
    "ResponseJupyterExecuteResponse",
    "ResponseJupyterInfoResponse",
    "ResponseList",
    "ResponseListBashSessionInfo",
    "ResponseListProxyMappingRoute",
    "ResponseListStr",
    "ResponseListToolsResultModel",
    "ResponseNodeJsCreateSessionResponse",
    "ResponseNodeJsDeleteSessionResponse",
    "ResponseNodeJsExecuteResponse",
    "ResponseNodeJsRuntimeInfo",
    "ResponseNodeJsSessionListResponse",
    "ResponseNodeJsSessionResponse",
    "ResponseNodeJsUpdateSessionResponse",
    "ResponseProxyDiagnoseResult",
    "ResponseProxyMappingRoute",
    "ResponseProxyUpstreamInfo",
    "ResponseShellCommandResult",
    "ResponseShellCreateSessionResponse",
    "ResponseShellKillResult",
    "ResponseShellViewResult",
    "ResponseShellWaitResult",
    "ResponseShellWriteResult",
    "ResponseSkillContentResult",
    "ResponseSkillMetadata",
    "ResponseSkillMetadataCollection",
    "ResponseSkillRegistrationResult",
    "ResponseStr",
    "ResponseStrReplaceEditorResult",
    "ResponseUnionProxyUpstreamInfoNoneType",
    "RestartRequest",
    "RightClickAction",
    "RouteResponseModel",
    "RuntimeEnv",
    "SandboxDetail",
    "SandboxResponse",
    "ScrollAction",
    "SessionInfo",
    "SessionStatus",
    "ShellCommandResult",
    "ShellCreateSessionResponse",
    "ShellKillResult",
    "ShellSessionInfo",
    "ShellViewResult",
    "ShellWaitResult",
    "ShellWriteResult",
    "SkillContentResult",
    "SkillMetadata",
    "SkillMetadataCollection",
    "SkillRegistrationResult",
    "StrReplaceEditorResult",
    "SystemEnv",
    "TextContent",
    "TextResourceContents",
    "Tool",
    "ToolAnnotations",
    "ToolCategory",
    "ToolExecution",
    "ToolExecutionTaskSupport",
    "ToolSpec",
    "TypingAction",
    "ValidationError",
    "ValidationErrorLocItem",
    "WaitAction",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .glob_file_info import GlobFileInfo


class FileGlobResult(UniversalBaseModel):
    """
    Enhanced glob result
    """

    path: str = pydantic.Field()
    """
    Base directory path
    """

    pattern: str = pydantic.Field()
    """
    Glob pattern used
    """

    files: typing.Optional[typing.List[GlobFileInfo]] = pydantic.Field(default=None)
    """
    List of matched files
    """

    total_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total number of matches
    """

    truncated: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether results were truncated
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
